# bayfiles-upload-script
An upload and download script for bayfiles.com made in python. Supports multiple files.

 [![PyPI version](https://badge.fury.io/py/bayfile.svg)](https://pypi.org/project/bayfile/)
 [![Downloads](https://pepy.tech/badge/bayfile/month)](https://pepy.tech/project/bayfile)
 [![Downloads](https://static.pepy.tech/personalized-badge/bayfile?period=total&units=international_system&left_color=green&right_color=blue&left_text=Total%20Downloads)](https://pepy.tech/project/bayfile)
 ![GitHub Contributors](https://img.shields.io/github/contributors/redevil1/bayfiles)
 ![GitHub commit activity](https://img.shields.io/github/commit-activity/m/redevil1/bayfiles)
 ![GitHub last commit](https://img.shields.io/github/last-commit/redevil1/bayfiles)
 ![Python 3.6](https://img.shields.io/badge/python-3.6-yellow.svg)


## Installation

```sh
pip3 install bayfile
```

## Usage 
```sh
bayfile up {path-to-file_1} {path-to-file _2} ...  # upload file to bayfiles server
bayfile d {url1} {url2} ...              # download file 
```
